{
  a Z-80 assembly language compiler for ZX-SPECTRUM (48/128/512/1024)

  DESCRIPT: Z80 instructions define.

                                 was written by SCREW/OHG/CM
                                   all rights reserved
}
const

{====== REGISTERS =======================================================}
 reg_B = 0;
 reg_C = 1;
 reg_D = 2;
 reg_E = 3;
 reg_H = 4;
 reg_L = 5;
 reg_atHL = 6;
 reg_A = 7;

 reg_BC = $0;
 reg_DE = $10;
 reg_HL = $20;
 reg_SP = $30;
 reg_AF = $30;

 modif_IX = $DD;
 modif_IY = $FD;

{============ FLAGS ====================================================}
 iff_NZ  = 0;
 iff_Z   = 8;
 iff_NC = 16;
 iff_C  = 24;
 iff_PO = 32;
 iff_PE = 40;
 iff_P  = 48;
 iff_M  = 56;


{============ LOAD =====================================================}
 mnem_LD_reg8num8   = $06;
 mnem_LD_reg16num16 = $01;
 mnem_LD_reg8reg8   = $40;

 mnem_LD_A_BC     = $0A;
 mnem_LD_A_DE     = $1A;
 mnem_LD_BC_A     = $02;
 mnem_LD_DE_A     = $12;

 mnem_LD_A_mem16     = $3A;
 mnem_LD_HL_mem16    = $2A;
 mnem_LD_reg16_mem16 = $ED4B;
 mnem_LD_mem16_A     = $32;
 mnem_LD_mem16_HL    = $22;
 mnem_LD_mem16_reg16 = $ED43;

 mnem_LD_SPfromHL   = $F9;

 mnem_LD_AfromR     = $ED5F;
 mnem_LD_RfromA     = $ED4F;
 mnem_LD_AfromI     = $ED57;
 mnem_LD_IfromA     = $ED47;

{============ ARIFMETIC ====================================================}
 mnem_INC_reg8      = $04;
 mnem_DEC_reg8      = $05;
 mnem_INC_reg16     = $03;
 mnem_DEC_reg16     = $0B;

 mnem_ADD_Anum8   = $C6;
 mnem_ADD_Areg8   = $80;
 mnem_ADD_HLreg16 = $09;

 mnem_ADC_Anum8   = $CE;
 mnem_ADC_Areg8   = $88;
 mnem_ADC_HLreg16 = $4A;

 mnem_SUB_Anum8   = $D6;
 mnem_SUB_Areg8   = $90;

 mnem_SBC_Anum8   = $DE;
 mnem_SBC_Areg8   = $98;
 mnem_SBC_HLreg16 = $ED42;


{============ LOGIC ========================================================}
 mnem_CP_Anum8  = $FE;
 mnem_CP_Areg8  = $B8;
 mnem_OR_Anum8  = $F6;
 mnem_OR_Areg8  = $B0;
 mnem_XOR_Anum8 = $EE;
 mnem_XOR_Areg8 = $A8;
 mnem_AND_Anum8 = $E6;
 mnem_AND_Areg8 = $A0;


{============ JUMP =========================================================}
 mnem_CALL_IF = $C4;
 mnem_CALL    = $CD;
 mnem_JP_IF   = $C2;
 mnem_JP      = $C3;
 mnem_JPatHL  = $E9;
 mnem_RET_IF  = $C0;
 mnem_RET     = $C9;
 mnem_JR_IF   = $20;
 mnem_JR      = $18;
 mnem_DJNZ    = $10;

 mnem_RST = $C7;

{============ STACK ====================================================}
 mnem_PUSH = $C5;
 mnem_POP  = $C1;


{============ ROTATION & BITS =============================================}
 mnem_SRL_reg8 = $CB38;
 mnem_SRA_reg8 = $CB28;
 mnem_SLA_reg8 = $CB20;
 mnem_SLI_reg8 = $CB30;
 mnem_RL_reg8  = $CB10;
 mnem_RR_reg8  = $CB18;
 mnem_RLC_reg8 = $CB00;
 mnem_RRC_reg8 = $CB08;

 mnem_SET_reg8 = $CBC0;
 mnem_RES_reg8 = $CB80;
 mnem_BIT_reg8 = $CB40;


{============ BLOCK WORK =============================================}
 tp_IR = 16;
 tp_DR = 24;
 tp_I = 0;
 tp_D = 8;

 mnem_LD_blk = $EDA0;
 mnem_CP_blk = $EDA1;
 mnem_IN_blk = $EDA2;
 mnem_OUT_blk = $EDA3;

{============ IN / OUT =================================================}

 mnem_OUT_reg8    = $ED41;
 mnem_OUT_port8_A = $D3;
 mnem_IN_reg8     = $ED40;
 mnem_IN_A_port8  = $DB;



{ UNGROUPPED MNEMONICS }



 mnem_RLA  = $17;
 mnem_RRA  = $1F;
 mnem_RLCA = $07;
 mnem_RRCA = $0F;
 mnem_RLD  = $ED6F;
 mnem_RRD  = $ED67;

 mnem_EX_DE_HL = $EB;
 mnem_EXX      = $D9;
 mnem_EX_AF_AF = $08;
 mnem_EX_SP_HL = $E3;

 mnem_EI = $FB;
 mnem_DI = $F3;
 mnem_IM0 = $ED46;
 mnem_IM1 = $ED56;
 mnem_IM2 = $ED5E;
 mnem_RETI = $ED4D;
 mnem_RETN = $ED45;
 mnem_NOP = $00;
 mnem_CPL = $2F;
 mnem_NEG = $ED44;
 mnem_SCF = $37;
 mnem_CCF = $3F;
 mnem_HALT = $76;
 mnem_DAA = $27;
